\begin{titlepage}
    \centering
    \ifcsempty{iodhbwm@institute@logo}{%
        \includegraphics[height=1.7cm]{\getDHBWLogo}
    }{%
        \begin{minipage}[c]{.25\textwidth}
            \includegraphics[width=\linewidth,keepaspectratio]{\getDHBWLogo}
        \end{minipage}
        \hfill
        \begin{minipage}[c]{.25\textwidth}
            \centering
            \includegraphics[width=\linewidth,keepaspectratio]{\getInstituteLogo}
        \end{minipage}
    }

    \bigskip
    
    \rule{\textwidth}{.5mm}\bigskip
    
    {\bfseries \getThesisTitle}\smallskip
    
    \rule{\textwidth}{.5mm}\bigskip

    \textsc{\Large Bachelorarbeit}
    
    \bigskip
    für die Prüfung zum
    
    \textsc{\large \getBachelorDegree}
    
    \bigskip
    des Studiengangs \getCourseName\par
    der Dualen Hochschule Baden-Württemberg \getDHBWLocation
    
    \vfill
    
    von\par
    {\bfseries\large \getAuthor}\bigskip
    
    Abgabe am \getSubmissionDate
    
    \vfill
    
    \small{%
        \begin{tabularx}{\textwidth}{@{}lX@{}}
        \toprule
        Bearbeitungszeitraum: & \getProcessingPeriod\\
        Matrikelnummer, Kurs: & \getStudentId, \getCourseId\\
        \ifcsempty{iodhbwm@institute@section}{}{Abteilung: & \getInstituteSection\\}%
        Ausbildungsbetrieb: & \getInstitute\\
        \ifbool{iodhbwm@if@print@location}{Ort: & \getLocation\\}{}%
        Betreuer des Ausbildungsbetriebs: & \getSupervisor\\
        Gutachter der Dualen Hochschule: & \getReviewer\\
        \end{tabularx}
    }
    \cleardoublepage
\end{titlepage}
