\begin{titlepage}
	\centering
    \begin{minipage}[c]{.25\textwidth}
        \includegraphics[width=\linewidth,keepaspectratio]{dhbw-logo}
    \end{minipage}
    \hfill
    \begin{minipage}[c]{.25\textwidth}
    	\raggedleft
        \includegraphics[width=\linewidth,keepaspectratio]{example-image}
    \end{minipage}
    
    \bigskip
    
    \Large\textsc{Report}
    
    \normalsize
    of the course Information Technology\par
    at the Baden-Wuerttemberg Cooperative State University \getDHBWLocation
    
    \rule{\textwidth}{.5mm}\bigskip
    
    \textsc{\large Subject \ifcsempty{iodhbwm@thesis@second@title}{}{A}}
    
    {\bfseries \getThesisTitle}\bigskip
    
    \ifcsempty{iodhbwm@thesis@second@title}{}{%
        \textsc{\large Subject B}\par
        %\tikz{\node (1) [draw, rounded rectangle] {Colloquium};}
        {\bfseries \getThesisSecondTitle}
    }{}
    
    \rule{\textwidth}{.5mm}
    
    \vfill
    
    \par
    {\bfseries\large \getAuthor}\par
    \today
    
    \vfill
    
    \small{%
    	\begin{tabularx}{\textwidth}{@{}lX@{}}
    	\toprule
   		Processing Period: & \getProcessingPeriod\\
    	Student id, course: & \getStudentId, \getCourseId\\
    	Department: & \getInstituteSection\\
    	Apprenticing company: & \getInstitute\\
	    Location: & \getLocation\\
	    Supervisor: & \getSupervisor\\
	    Signature of supervisor & \rule[-.5cm]{.5\columnwidth}{.5pt}
    	\end{tabularx}
    }
    \cleardoublepage
\end{titlepage}
