\ifcsdef{chapter}%
{\chapter*{Erklärung}}%
{\section*{Erklärung}}

\thispagestyle{empty}

\bigskip

Ich versichere hiermit, dass ich meine \getThesisType{} mit dem\bigskip

\textsc{Thema \ifcsempty{iodhbwm@thesis@second@title}{}{A}}

{\bfseries \getThesisTitle}

\ifcsempty{iodhbwm@thesis@second@title}{}{%
    \bigskip
    \textsc{Thema B}\par%
    {\bfseries \getThesisSecondTitle}%
}{}\bigskip

selbstständig verfasst und keine anderen als die angegebenen Quellen und Hilfsmittel benutzt habe.


Ich versichere zudem, dass die eingereichte elektronische Fassung mit der gedruckten Fassung übereinstimmt.$^\ast$

{\small$^\ast$ falls beide Fassungen gefordert sind}

\vfill

\begin{tabular}{l}
    \hline
    \getLocation, den \getDate
\end{tabular}

\clearpage
