\begin{titlepage}
    \centering
    \ifcsempty{iodhbwm@institute@logo}{%
        \includegraphics[height=1.5cm]{\getDHBWLogo}
    }{%
        \begin{minipage}[c]{.25\textwidth}
            \includegraphics[width=\linewidth,keepaspectratio]{\getDHBWLogo}
        \end{minipage}
        \hfill
        \begin{minipage}[c]{.25\textwidth}
            \raggedleft
            \includegraphics[width=\linewidth,keepaspectratio]{\getInstituteLogo}
        \end{minipage}
    }

    \bigskip
    
    \Large\textsc{Project report}
    
    \normalsize
    of the course \getCourseName\par
    at the Baden-Wuerttemberg Cooperative State University \getDHBWLocation
    
    \rule{\textwidth}{.5mm}\bigskip
    
    \textsc{\large Subject \ifcsempty{iodhbwm@thesis@second@title}{}{A}}
    
    {\bfseries \getThesisTitle}\bigskip
    
    \ifcsempty{iodhbwm@thesis@second@title}{}{%
        \textsc{\large Subject B}\par
        %\tikz{\node (1) [draw, rounded rectangle] {Colloquium};}
        {\bfseries \getThesisSecondTitle}
    }{}
    
    \rule{\textwidth}{.5mm}
    
    \vfill
    
    \par
    {\bfseries\large \getAuthor}\par
    \getDate
    
    \vfill
    
    \small{%
        \begin{tabularx}{\textwidth}{@{}lX@{}}
        \toprule
        Processing Period: & \getProcessingPeriod\\
        Student id, course: & \getStudentId, \getCourseId\\
        \ifcsempty{iodhbwm@institute@section}{}{Department: & \getInstituteSection\\}%
        Apprenticing company: & \getInstitute\\
        \ifbool{iodhbwm@if@print@location}{Location: & \getLocation\\}{}%
        Supervisor: & \getSupervisor\\
        Signature of supervisor & \rule[-.5cm]{.5\columnwidth}{.5pt}
        \end{tabularx}
    }
    \cleardoublepage
\end{titlepage}
